### -*- coding: utf-8 -*- ############################################
### Author: Ilshad Habibullin, 2008 <astoon.net@gmail.com> ###########
######################################################################

__license__ = "GPL v.3"

from zope.interface import Interface

class IManageUITemplate(Interface):
    """ Customizable template """

class IUndoTemplate(Interface):
    """ Customizable template """
