.manage-adverlets form {
    margin-top:10px;
    margin-bottom:2px;
}

.manage-adverlets .preview-adverlet {
    margin:5px;
    padding:10px;
    border:1px solid #7793ad;
}

.manage-adverlets fieldset {
    border:1px solid #7793ad;
    background-color:#cbdded;
    margin:5px;
}

.manage-adverlets legend {
    font-weight:bold;
    color:#7793ad;
}

.manage-adverlets label {
    color:#7793ad;
}

.manage-adverlets select {
    border:1px solid #bcbcbc;
    color:gray;
    font-weight:bold;
}

.manage-adverlets input.textType,
.manage-adverlets input.fileType {
    border:1px solid #b8cbdc;
    color:gray;
    font-weight:bold;
}

.manage-adverlets input[type=submit] {
    border:1px solid #b8cbdc;
    color:gray;
    font-weight:bold;
    background:#fff url(/++resource++ice.adverlet.resources/text-bg.gif) repeat-x scroll 0pt 0pt;
    width:100px;
}

.manage-adverlets button {
    border:1px solid #b8cbdc;
    color:gray;
    font-weight:bold;
    background:#fff url(/++resource++ice.adverlet.resources/text-bg.gif) repeat-x scroll 0pt 0pt;
    width:50px;
}

.ice-adverlet-form-checkbox .label {
    float:right;
}

.ice-adverlet-form-checkbox .field {
    margin-left:10px;
    float:right;
}

.ice-adverlet-form-text textarea {
    width:100%;
}

.manage-adverlets .mceToolbarTop {
    background:#cbdded;
}

.manage-adverlets .mceEditor {
    border:0px;
    margin-bottom:10px;
}

.manage-adverlets a.mceButtonNormal img,
.manage-adverlets a.mceButtonSelected img {
    border:1px solid #b8cbdc !important;
}

.manage-adverlets .mceSelectList,
.manage-adverlets .mceOpen {
    background-color:#fff;
    border:1px solid #b8cbdc;
    font-size:12px !important;
    font-weight:bold;
    color:gray;
}

.manage-adverlets .mceStatusbarBottom {
    border-top:0px;
    background-color:#cbdded;
    color:#7793ad;
}

.manage-adverlets .mceStatusbarBottom a {
    color:#7793ad;
}

.manage-adverlets .adverlets-list {
    margin:0px 5px;
}

.manage-adverlets .adverlets-list table {
    border:1px solid #7793ad;
    background-color:#cbdded;
    border-collapse:collapse;
}

.manage-adverlets .adverlets-list th {
    font-weight:bold;
    color:#fff;
    background:#7793ad;
    text-align:center;
    padding:3px;
}

.manage-adverlets .adverlets-list a {
    color:#6e869b;
    text-decoration:none;
}

.manage-adverlets .adverlets-list a:hover {
    color:#48657e;
    text-decoration:underline;
}

.manage-adverlets .adverlets-list td {
    text-align:left;
    color:#333;
    font-size:8pt;
    font-family:"Arial","Helvetica",sans-serif;
    padding:1px 1px 1px 5px;
    border-bottom:1px dashed #b8cbdc;
    border-right:1px dashed #b8cbdc;
}


.manage-adverlets .adverlets-list tr.current td {
    background-color:#afc6db;
}

.manage-adverlets .adverlets-list td.centred {
    text-align:center;
}

.info-adverlets {
    margin:5px;
    padding:10px;
    border:1px solid #7793ad;
    background:#cbdded;
    text-align:left;
    color:#4f6a84;
    font-size:9pt;
    font-family:"Arial","Helvetica",sans-serif;
}

.manage-adverlets .adverlets-list td.product-copyright {
    font-size:6pt;
    text-align:right;
    color:#6e869b;
}

.manage-adverlets .adverlets-list td.product-copyright a {
    font-weight:bold;
}

.manage-adverlets td.adverlets-menu {
    border-top:1px solid #7793ad;
    border-bottom:0px;
    background:#7793ad;
    font-size:10pt;
}

.manage-adverlets td.adverlets-menu a {
    text-decoration:none;
    color:#fff;
}

.manage-adverlets td.adverlets-menu a:hover {
    text-decoration:underline;
    color:yellow;
}

.manage-adverlets .adverlets-files,
.manage-adverlets .adverlets-undo {
    margin:5px;
}

.manage-adverlets .adverlets-files th {
    font-size:11pt;
}

.manage-adverlets .adverlets-files td,
.manage-adverlets .adverlets-undo td {
    font-size:8pt;
}

.manage-adverlets .summary,
.manage-adverlets .error {
    font-weight:bold;
    color:darkgreen;
}

.manage-adverlets .error {
    font-size:10pt;
}

.manage-adverlets .undo-undo {
    color:darkgreen;
}

.help-adverlets {
    margin:5px;
    padding:5px;
    border:1px solid #7793ad;
    background:#cbdded;
    text-align:left;
    color:#333;
    font-size:8pt;
    font-family:"Arial","Helvetica",sans-serif;
}

.help-adverlets dt {
    font-weight:bold;
    margin-top:5pt;
    color:#4f6a84;
}
